==> nextcloud-25.0.7.tgz: nextcloud/apps/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Local" : "Lokal",
    "Federated" : "Federated",
    "Published" : "Publisert",
    "Verify" : "Stadfest",
    "Verifying …" : "Stadfestar…",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "Group list is empty" : "Gruppelista er tom",
    "Apps" : "Applikasjonar",
    "Wrong password" : "Feil passord",
    "Saved" : "Lagra",
    "No user supplied" : "Ingen brukar gjeve",
    "Authentication error" : "Autentiseringsfeil",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Administrator documentation" : "Administratordokumentasjon",
    "User documentation" : "Brukardokumentasjon",
    "Users" : "Brukarare",
    "Invalid mail address" : "Ugyldig e--postadresse",
    "Welcome aboard" : "Velkomen ombord",
    "Welcome aboard %s" : "Velkomen ombord %s",
    "Your username is: %s" : "Brukarnamnet ditt er: %s",
    "Set your password" : "Vel eit passord",
    "Go to %s" : "Gå til %s",
    "Install Client" : "Installer klient",
    "Settings" : "Instillingar",
    "Personal" : "Personleg",
    "Administration" : "Administrasjon",
    "Additional settings" : "Tilleggsinnstillingar",
    "Overview" : "Oversyn",
    "Sharing" : "Deling",
    "Calendar" : "Kalendar",
    "Personal info" : "Personleg informasjon",
    "Email server" : "E-postserver",
    "Create" : "Lag",
    "Delete" : "Slett",
    "Unlimited" : "Ubegrensa",
    "None" : "Ingen",
    "All" : "Alle",
    "Remove" : "Fjern",
    "Disable" : "Slå av",
    "Visit website" : "Besøk nettstaden",
    "Report a bug" : "Rapporter feil",
    "Admin documentation" : "Admin-dokumentasjon",
    "Rename" : "Gje nytt namn",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "This session" : "Denne økta",
    "Device" : "Eining",
    "Last activity" : "Siste aktivitet",
    "App name" : "App-namn",
    "Username" : "Brukarnamn",
    "Password" : "Passord",
    "Done" : "Ferdig",
    "Copied!" : "Kopiert!",
    "Copy" : "Kopier",
    "Enable" : "Slå på",
    "Server-side encryption" : "Tenarsidekryptering",
    "Enable server-side encryption" : "Aktiver tenarsidekryptering",
    "Select default encryption module:" : "Vel standard krypteringsmodul:",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Cancel" : "Avbryt",
    "Details" : "Detaljar",
    "Your email address" : "Di e-postadresse",
    "Language" : "Språk",
    "Help translate" : "Hjelp oss å omsetja",
    "Add" : "Legg til",
    "Email" : "E-post",
    "Avatar" : "Avatar",
    "Quota" : "Kvote",
    "Last login" : "Siste innlogging",
    "Add group" : "Legg til gruppe",
    "Active users" : "Aktive brukarare",
    "Email sent" : "E-post sendt",
    "Location" : "Stad",
    "Profile picture" : "Profilbilete",
    "About" : "Om",
    "Full name" : "Fult namn",
    "Hide" : "Gøym",
    "Never" : "Aldri",
    "Documentation" : "Dokumentasjon",
    "Forum" : "Forum",
    "Login" : "Logg inn",
    "Open documentation" : "Opne dokumentasjon",
    "Encryption" : "Kryptering",
    "From address" : "Frå adresse",
    "Server address" : "Tenaradresse",
    "Port" : "Port",
    "Credentials" : "Credentials",
    "SMTP Username" : "SMTP-brukarnamn",
    "Save" : "Lagre",
    "Send email" : "Send e-post",
    "Version" : "Utgåve",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "Allow resharing" : "Tillat vidaredeling",
    "Allow sharing with groups" : "Tillat deling med grupper",
    "Like our Facebook page" : "Fylj på Facebook",
    "Follow us on Twitter" : "Fylj på Twitter",
    "Check out our blog" : "Les våre nettsider",
    "Subscribe to our newsletter" : "Abonner på nyhende",
    "Select a profile picture" : "Vel eit profilbilete",
    "Couldn't remove app." : "Klarte ikkje å fjerne appen.",
    "Couldn't update app." : "Klarte ikkje oppdatera programmet.",
    "Migration started …" : "Overføring har starta…",
    "Address" : "Adresse",
    "Enable encryption" : "Aktiver kryptering",
    "Start migration" : "Start migrasjon",
    "Upload new" : "Last opp ny",
    "Select from Files" : "Vel frå filer",
    "Remove image" : "Fjern bilete",
    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB",
    "Choose as profile picture" : "Vel eit profilbilete"
},
"nplurals=2; plural=(n != 1);");

==> nextcloud-25.0.8.tgz: nextcloud/apps/settings/l10n/nn_NO.js <==
OC.L10N.register(
    "settings",
    {
    "Private" : "Privat",
    "Local" : "Lokal",
    "Federated" : "Federated",
    "Published" : "Publisert",
    "Verify" : "Stadfest",
    "Verifying …" : "Stadfestar…",
    "Unable to change password" : "Klarte ikkje å endra passordet",
    "Very weak password" : "Veldig svakt passord",
    "Weak password" : "Svakt passord",
    "So-so password" : "Middelmåtig passord",
    "Good password" : "OK passord",
    "Strong password" : "Sterkt passord",
    "Groups" : "Grupper",
    "Group list is empty" : "Gruppelista er tom",
    "Apps" : "Applikasjonar",
    "Wrong password" : "Feil passord",
    "Saved" : "Lagra",
    "No user supplied" : "Ingen brukar gjeve",
    "Authentication error" : "Autentiseringsfeil",
    "Wrong admin recovery password. Please check the password and try again." : "Feil admingjenopprettingspassord. Ver venleg og sjekk passordet og prøv igjen.",
    "Administrator documentation" : "Administratordokumentasjon",
    "User documentation" : "Brukardokumentasjon",
    "Users" : "Brukarare",
    "Invalid mail address" : "Ugyldig e--postadresse",
    "Welcome aboard" : "Velkomen ombord",
    "Welcome aboard %s" : "Velkomen ombord %s",
    "Your username is: %s" : "Brukarnamnet ditt er: %s",
    "Set your password" : "Vel eit passord",
    "Go to %s" : "Gå til %s",
    "Install Client" : "Installer klient",
    "Settings" : "Instillingar",
    "Personal" : "Personleg",
    "Administration" : "Administrasjon",
    "Additional settings" : "Tilleggsinnstillingar",
    "Overview" : "Oversyn",
    "Sharing" : "Deling",
    "Calendar" : "Kalendar",
    "Personal info" : "Personleg informasjon",
    "Email server" : "E-postserver",
    "Create" : "Lag",
    "Delete" : "Slett",
    "Unlimited" : "Ubegrensa",
    "None" : "Ingen",
    "All" : "Alle",
    "Remove" : "Fjern",
    "Disable" : "Slå av",
    "Visit website" : "Besøk nettstaden",
    "Report a bug" : "Rapporter feil",
    "Admin documentation" : "Admin-dokumentasjon",
    "Rename" : "Gje nytt namn",
    "Internet Explorer" : "Internet Explorer",
    "Edge" : "Edge",
    "Firefox" : "Firefox",
    "Google Chrome" : "Google Chrome",
    "Safari" : "Safari",
    "Google Chrome for Android" : "Google Chrome for Android",
    "This session" : "Denne økta",
    "Device" : "Eining",
    "Last activity" : "Siste aktivitet",
    "App name" : "App-namn",
    "Username" : "Brukarnamn",
    "Password" : "Passord",
    "Done" : "Ferdig",
    "Copied!" : "Kopiert!",
    "Copy" : "Kopier",
    "Enable" : "Slå på",
    "Server-side encryption" : "Tenarsidekryptering",
    "Enable server-side encryption" : "Aktiver tenarsidekryptering",
    "Select default encryption module:" : "Vel standard krypteringsmodul:",
    "Current password" : "Passord",
    "New password" : "Nytt passord",
    "Change password" : "Endra passord",
    "Cancel" : "Avbryt",
    "Details" : "Detaljar",
    "Your email address" : "Di e-postadresse",
    "Language" : "Språk",
    "Help translate" : "Hjelp oss å omsetja",
    "Add" : "Legg til",
    "Email" : "E-post",
    "Quota" : "Kvote",
    "Last login" : "Siste innlogging",
    "Add group" : "Legg til gruppe",
    "Active users" : "Aktive brukarare",
    "Email sent" : "E-post sendt",
    "Location" : "Stad",
    "Profile picture" : "Profilbilete",
    "About" : "Om",
    "Full name" : "Fult namn",
    "Hide" : "Gøym",
    "Never" : "Aldri",
    "Documentation" : "Dokumentasjon",
    "Forum" : "Forum",
    "Login" : "Logg inn",
    "Open documentation" : "Opne dokumentasjon",
    "Encryption" : "Kryptering",
    "From address" : "Frå adresse",
    "Server address" : "Tenaradresse",
    "Port" : "Port",
    "Authentication" : "Godkjenning",
    "Credentials" : "Credentials",
    "SMTP Username" : "SMTP-brukarnamn",
    "Save" : "Lagre",
    "Send email" : "Send e-post",
    "Version" : "Utgåve",
    "Allow apps to use the Share API" : "La app-ar bruka API-et til deling",
    "Allow public uploads" : "Tillat offentlege opplastingar",
    "Allow resharing" : "Tillat vidaredeling",
    "Allow sharing with groups" : "Tillat deling med grupper",
    "Like our Facebook page" : "Fylj på Facebook",
    "Follow us on Twitter" : "Fylj på Twitter",
    "Check out our blog" : "Les våre nettsider",
    "Subscribe to our newsletter" : "Abonner på nyhende",
    "png or jpg, max. 20 MB" : "png eller jpg, maks. 20 MB"
},
"nplurals=2; plural=(n != 1);");
